@@ -3,28 +3,15 @@ import argparse
 import json
 import os
 import urlparse
+import yaml
+from avi.migrationtools.avi_migration_utils import MigrationUtil
 
-path_key_map = {'poolgroup': 'PoolGroup', 'healthmonitor': 'HealthMonitor',
-                'sslprofile': 'SSLProfile', 'httppolicyset': 'HTTPPolicySet',
-                'sslkeyandcertificate': 'SSLKeyAndCertificate', 'pool': 'Pool',
-                'networkprofile': 'NetworkProfile', 'pkiprofile': 'PKIProfile',
-                'stringgroup': 'StringGroup', 'vrfcontext': 'VrfContext',
-                'applicationprofile': 'ApplicationProfile', 'vsdatascriptset':
-                    'VSDataScriptSet', 'networksecuritypolicy':
-                    'NetworkSecurityPolicy', 'applicationpersistenceprofile':
-                    'ApplicationPersistenceProfile', 'prioritylabels':
-                    'PriorityLabels', 'vsvip': 'VsVip'
-                }
+# Read avi object to API path map from yaml file.
+mg_util = MigrationUtil()
 
+path_key_map = mg_util.get_path_key_map()
 
-def get_name_and_entity(url):
-    """
-    Parses reference string to extract object type and
-    :param url: reference url to be parsed
-    :return: entity and object name
-    """
-    parsed = urlparse.urlparse(url)
-    return parsed.path.split('/')[2], urlparse.parse_qs(parsed.query)['name'][0]
+warning_list = []
 
 
 def filter_for_vs(avi_config, vs_names):
@@ -35,7 +22,6 @@ def filter_for_vs(avi_config, vs_names):
     :return: Filtered config dict
     """
     new_config = dict()
-    new_config['META'] = avi_config['META']
     new_config['VirtualService'] = []
     virtual_services = vs_names.split(',')
 
@@ -43,12 +29,17 @@ def filter_for_vs(avi_config, vs_names):
         vs = [vs for vs in avi_config['VirtualService']
               if vs['name'] == vs_name]
         if not vs:
-            print 'ERROR: VS object not found with name %s' % vs_name
-            exit()
+            vs_log = 'WARNING: VS object not found with name %s' % vs_name
+            warning_list.append(vs_log)
+            continue
         vs = vs[0]
         new_config['VirtualService'].append(vs)
         print '%s(VirtualService)' % vs_name
         find_and_add_objects(vs, avi_config, new_config, depth=0)
+
+    for warn in warning_list:
+        print("\033[1;33;50m  %s   \033[0m" %(warn))
+
     return new_config
 
 
@@ -72,9 +63,11 @@ def search_obj(entity, name, new_config, avi_config, depth):
                     'sslkeyandcertificate', 'sslprofile']:
         if str.startswith(str(name), 'System-'):
             return
+    elif entity == 'vrfcontext':
+        return
     else:
-        print 'ERROR: Reference not found for %s with name %s' % (entity, name)
-        exit()
+        print 'WARNING: Reference not found for %s with name %s' % (entity, name)
+        return
     if avi_conf_key in new_config:
         if not any(d['name'] == found_obj['name'] for d in
                    new_config[avi_conf_key]):
@@ -94,15 +87,15 @@ def find_and_add_objects(obj_dict, avi_config, new_config, depth):
     :param depth: Recursion depth to determine level in the vs reference tree
     """
     for key in obj_dict:
-        if (key.endswith('ref') and key not in ['cloud_ref', 'tenant_ref']) \
+        if (key.endswith('ref') and key not in ['cloud_ref', 'tenant_ref', 'se_group_ref']) \
                 or key == 'ssl_profile_name':
             if not obj_dict[key]:
                 continue
-            entity, name = get_name_and_entity(obj_dict[key])
+            entity, name = mg_util.get_name_and_entity(obj_dict[key])
             search_obj(entity, name, new_config, avi_config, depth)
         elif key.endswith('refs'):
             for ref in obj_dict[key]:
-                entity, name = get_name_and_entity(ref)
+                entity, name = mg_util.get_name_and_entity(ref)
                 search_obj(entity, name, new_config, avi_config, depth)
         elif isinstance(obj_dict[key], dict):
             find_and_add_objects(obj_dict[key], avi_config, new_config, depth)
